Ti.UI.setBackgroundColor('#000');

var tabGroup = Ti.UI.createTabGroup();

function buildButton(title, onclick) {
	var b = Ti.UI.createButton({
		title: title,
		height: 30
	});
	b.addEventListener("click", onclick);
	return b;
}

function buildTab(props) {
	var win = Ti.UI.createWindow({ backgroundColor:'#fff' }),
		tab = Ti.UI.createTab({  
		    icon:'KS_nav_views.png',
	    	title:props.title,
		    window:win
		}),
		width = props.width || 300,
		output = Ti.UI.createScrollView({
			left: width + 12,
			width: 500,
			height: 250
		}),
		videoProps = {
			url: ["sample.m4v", "sample.theora.ogv", "sample.webm"],
			width: width,
			height: 250,
			borderWidth: 2,
			borderColor: "#f00"
		};

	function log(msg) {
		console.debug(msg);
		output.add(Ti.UI.createLabel({
			text:msg,
			font:{fontSize:11,fontFamily:'Helvetica Neue'},
			textAlign:'left',
			width:'auto'
		}));
		output.scrollTo(null, 99999999);
	}

	props.scalingMode && (videoProps.scalingMode = props.scalingMode);
	props.autoplay && (videoProps.autoplay = props.autoplay);
	props.mediaControlStyle && (videoProps.mediaControlStyle = props.mediaControlStyle);
	props.repeatMode && (videoProps.repeatMode = props.repeatMode);
	props.fullscreen && (videoProps.fullscreen = props.fullscreen);

	win.add(output);

	var m = Ti.Media.createVideoPlayer(videoProps);
	m.addEventListener("playbackState", function(e) {
		var s = "Unknown";
		switch (e.playbackState) {
			case Ti.Media.VIDEO_PLAYBACK_STATE_STOPPED: s = "VIDEO_PLAYBACK_STATE_STOPPED"; break;
			case Ti.Media.VIDEO_PLAYBACK_STATE_PLAYING: s = "VIDEO_PLAYBACK_STATE_PLAYING"; break;
			case Ti.Media.VIDEO_PLAYBACK_STATE_PAUSED:  s = "VIDEO_PLAYBACK_STATE_PAUSED";  break;
		}
		log('Event "playbackState": ' + s);
	});
	m.addEventListener("loadstate", function(e) {
		var s = "Unknown";
		switch (e.loadState) {
			case Ti.Media.VIDEO_LOAD_STATE_PLAYABLE:       s = "VIDEO_LOAD_STATE_PLAYABLE";       break;
			case Ti.Media.VIDEO_LOAD_STATE_PLAYTHROUGH_OK: s = "VIDEO_LOAD_STATE_PLAYTHROUGH_OK"; break;
			case Ti.Media.VIDEO_LOAD_STATE_STALLED:        s = "VIDEO_LOAD_STATE_STALLED";        break;
			case Ti.Media.VIDEO_LOAD_STATE_UNKNOWN:        s = "VIDEO_LOAD_STATE_UNKNOWN";        break;
		}
		log('Event "loadstate": ' + s);
	});
	m.addEventListener("complete", function(e) {
		var s = "Unknown";
		switch (e.reason) {
			case Ti.Media.VIDEO_FINISH_REASON_PLAYBACK_ENDED: s = "VIDEO_FINISH_REASON_PLAYBACK_ENDED"; break;
			case Ti.Media.VIDEO_FINISH_REASON_PLAYBACK_ERROR: s = "VIDEO_FINISH_REASON_PLAYBACK_ERROR"; break;
			case Ti.Media.VIDEO_FINISH_REASON_USER_EXITED:    s = "VIDEO_FINISH_REASON_USER_EXITED";    break;
		}
		log('Event "complete": ' + s);
	});
	m.addEventListener("durationAvailable", function(e) {
		log('Event "durationAvailable": ' + e.duration);
	});
	m.addEventListener("load", function(e) {
		log('Event "load"');
	});
	m.addEventListener("preload", function(e) {
		log('Event "preload"');
	});
	m.addEventListener("error", function(e) {
		log('Event "error": ' + e.message);
	});
	win.add(m);

	win.add(buildButton("Play", function(){
		if (m.playing) {
			log("Video already playing");
		} else {
			log("Playing video");
			m.play();
		}
	}));

	win.add(buildButton("Pause", function(){
		if (m.playing) {
			log("Pausing video");
			m.pause();
		} else {
			log("Video already paused");
		}
	}));

	win.add(buildButton("Stop", function(){
		log("Stopping video");
		m.stop();
	}));

	win.add(buildButton("Fullscreen", function(){
		m.fullscreen = !m.fullscreen;
		log((m.fullscreen ? "Entering" : "Exiting") + " fullscreen");
	}));

	win.add(buildButton("Scaling Mode", function(){
		m.scalingMode = m.scalingMode == Ti.Media.VIDEO_SCALING_NONE ? Ti.Media.VIDEO_SCALING_ASPECT_FIT : Ti.Media.VIDEO_SCALING_NONE;
		this.title = m.scalingMode == Ti.Media.VIDEO_SCALING_NONE ? "Scaling Mode: none" : "Scaling Mode: aspect fit";
	}));

	win.add(buildButton("Controls: " + (m.mediaControlStyle === Ti.Media.VIDEO_CONTROL_DEFAULT ? "on" : "off"), function(){
		m.mediaControlStyle = m.mediaControlStyle === Ti.Media.VIDEO_CONTROL_DEFAULT ? Ti.Media.VIDEO_CONTROL_NONE : Ti.Media.VIDEO_CONTROL_DEFAULT;
		console.debug(m.mediaControlStyle);
		console.debug(this);
		this.title = "Controls: " + (m.mediaControlStyle === Ti.Media.VIDEO_CONTROL_DEFAULT ? "on" : "off");
		log("Turned controls " + (m.mediaControlStyle === Ti.Media.VIDEO_CONTROL_DEFAULT ? "on" : "off"));
	}));

	win.add(buildButton("Repeat: " + (m.repeatMode === Ti.Media.VIDEO_REPEAT_MODE_ONE ? "on" : "off"), function(){
		m.repeatMode = m.repeatMode === Ti.Media.VIDEO_REPEAT_MODE_NONE ? Ti.Media.VIDEO_REPEAT_MODE_ONE : Ti.Media.VIDEO_REPEAT_MODE_NONE;
		console.debug(m.repeatMode);
		console.debug(this);
		this.title = "Repeat: " + (m.repeatMode === Ti.Media.VIDEO_REPEAT_MODE_ONE ? "on" : "off");
		log("Turned repeat " + (m.repeatMode === Ti.Media.VIDEO_REPEAT_MODE_ONE ? "on" : "off"));
	}));

	win.add(buildButton("Change video", function(){
		var s = "sample2", x;
		if (m.url instanceof Array || typeof m.url == "array") {
			m.url[0].indexOf("sample2") !== -1 && (s = "sample");
		} else {
			m.url.indexOf("sample2") !== -1 && (s = "sample");
		}
		log("Changing video to " + s);
		m.url = [s + ".m4v", s + ".theora.ogv", s + ".webm"];
	}));

	win.add(buildButton("Release", function(){
		log("Nuking the video DOM node");
		m.release();
	}));

	return tab;
}

tabGroup.addTab(buildTab({
	title: "Autoplay, repeat",
	// note to tester, best to test fullscreen on the first tab
	// fullscreen: true,
	//repeatMode: Ti.Media.VIDEO_REPEAT_MODE_ONE,
	autoplay: true
}));

tabGroup.addTab(buildTab({
	title: "Default settings"
}));

tabGroup.addTab(buildTab({
	title: "No video scaling",
	scalingMode: Ti.Media.VIDEO_SCALING_NONE
}));

tabGroup.addTab(buildTab({
	title: "No controls, wide",
	mediaControlStyle: Ti.Media.VIDEO_CONTROL_NONE,
	width: 600
}));

tabGroup.open();